@@ -18,4 +18,13 @@
 # ------------------------------------------------------------------------------
 """This module contains the common types and interfaces used in the aea framework."""
 
+from typing import Any, Dict, List, Optional, Union
+
+
 Address = str
+
+Primitive = Union[str, int, bool, float]
+_JSONDict = Dict[Any, Any]  # temporary placeholder
+_JSONList = List[Any]  # temporary placeholder
+_JSONType = Optional[Union[Primitive, _JSONDict, _JSONList]]
+JSONLike = Dict[str, _JSONType]
