@@ -206,7 +206,7 @@ class PackageConfiguration(Configuration, ABC):
 
     default_configuration_filename: str
     package_type: PackageType
-    FIELDS_ALLOWED_TO_UPDATE: FrozenSet[str] = frozenset()
+    FIELDS_ALLOWED_TO_UPDATE: FrozenSet[str] = frozenset(["build_directory"])
     schema: str
     CHECK_EXCLUDES: List[Tuple[str]] = []
 
@@ -250,7 +250,7 @@ class PackageConfiguration(Configuration, ABC):
             else []
         )
         self.build_entrypoint = build_entrypoint
-        self.aea_version = aea_version if aea_version != "" else __aea_version__
+        self._aea_version = aea_version if aea_version != "" else __aea_version__
         self._aea_version_specifiers = self._parse_aea_version_specifier(aea_version)
 
         self._directory = None  # type: Optional[Path]
@@ -275,6 +275,19 @@ class PackageConfiguration(Configuration, ABC):
         """Set the author."""
         self._author = SimpleId(value)
 
+    @property
+    def aea_version(self):
+        """Get the 'aea_version' attribute."""
+        return self._aea_version
+
+    @aea_version.setter
+    def aea_version(self, new_aea_version: str):
+        """Set the 'aea_version' attribute."""
+        self._aea_version_specifiers = self._parse_aea_version_specifier(
+            new_aea_version
+        )
+        self._aea_version = new_aea_version
+
     @property
     def directory(self) -> Optional[Path]:
         """Get the path to the configuration file associated to this file, if any."""
@@ -524,7 +537,7 @@ class ConnectionConfig(ComponentConfiguration):
     schema = "connection-config_schema.json"
 
     FIELDS_ALLOWED_TO_UPDATE: FrozenSet[str] = frozenset(
-        ["config", "cert_requests", "is_abstract"]
+        ["config", "cert_requests", "is_abstract", "build_directory"]
     )
 
     def __init__(
@@ -855,7 +868,7 @@ class SkillConfig(ComponentConfiguration):
     abstract_field_name = "is_abstract"
 
     FIELDS_ALLOWED_TO_UPDATE: FrozenSet[str] = frozenset(
-        ["behaviours", "handlers", "models", "is_abstract"]
+        ["behaviours", "handlers", "models", "is_abstract", "build_directory"]
     )
     FIELDS_WITH_NESTED_FIELDS: FrozenSet[str] = frozenset(
         ["behaviours", "handlers", "models"]
@@ -1551,7 +1564,7 @@ class ContractConfig(ComponentConfiguration):
     package_type = PackageType.CONTRACT
     schema = "contract-config_schema.json"
 
-    FIELDS_ALLOWED_TO_UPDATE: FrozenSet[str] = frozenset([])
+    FIELDS_ALLOWED_TO_UPDATE: FrozenSet[str] = frozenset(["build_directory"])
 
     def __init__(
         self,
