@@ -146,6 +146,7 @@ class MultiAgentManager:
         self._projects: Dict[PublicId, Project] = {}
         self._versionless_projects_set: Set[PublicId] = set()
         self._keys_dir = os.path.abspath(os.path.join(self.working_dir, "keys"))
+        self._certs_dir = os.path.abspath(os.path.join(self.working_dir, "certs"))
         self._agents: Dict[str, AgentAlias] = {}
         self._agents_tasks: Dict[str, AgentRunAsyncTask] = {}
 
@@ -162,6 +163,16 @@ class MultiAgentManager:
         self._started_event = threading.Event()
         self._mode = mode
 
+    @property
+    def keys_dir(self) -> str:
+        """Get the keys directory."""
+        return self._keys_dir
+
+    @property
+    def certs_dir(self) -> str:
+        """Get the certs directory."""
+        return self._certs_dir
+
     @property
     def is_running(self) -> bool:
         """Is manager running."""
@@ -282,7 +293,8 @@ class MultiAgentManager:
     def _cleanup(self, only_keys: bool = False) -> None:
         """Remove workdir if was created."""
         if only_keys:
-            rmtree(self._keys_dir)
+            rmtree(self.keys_dir)
+            rmtree(self.certs_dir)
         else:
             if self._was_working_dir_created and os.path.exists(self.working_dir):
                 rmtree(self.working_dir)
@@ -377,7 +389,7 @@ class MultiAgentManager:
         project = self._projects[public_id]
 
         agent_alias = AgentAlias(
-            project=project, agent_name=agent_name, keys_dir=self._keys_dir,
+            project=project, agent_name=agent_name, keys_dir=self.keys_dir,
         )
         agent_alias.set_overrides(agent_overrides, component_overrides)
         project.agents.add(agent_name)
@@ -409,7 +421,7 @@ class MultiAgentManager:
         project = self._projects[public_id]
 
         agent_alias = AgentAlias(
-            project=project, agent_name=agent_name, keys_dir=self._keys_dir,
+            project=project, agent_name=agent_name, keys_dir=self.keys_dir,
         )
         agent_alias.set_agent_config_from_data(config)
         project.agents.add(agent_name)
@@ -516,12 +528,8 @@ class MultiAgentManager:
         if self._is_agent_running(agent_name):
             raise ValueError(f"{agent_name} is already started!")
 
-        agent_alias.issue_certificates()
         aea = agent_alias.get_aea_instance()
-        # override build dir to project's one
-        aea.DEFAULT_BUILD_DIR_NAME = os.path.join(
-            agent_alias.project.path, aea.DEFAULT_BUILD_DIR_NAME
-        )
+
         if self._mode == "async":
             task = AgentRunAsyncTask(aea, self._loop)
         elif self._mode == "threaded":
@@ -648,8 +656,10 @@ class MultiAgentManager:
 
         if not os.path.isdir(self.working_dir):  # pragma: nocover
             raise ValueError(f"{self.working_dir} is not a directory!")
-        if not os.path.exists(self._keys_dir):
-            os.makedirs(self._keys_dir)
+        if not os.path.exists(self.keys_dir):
+            os.makedirs(self.keys_dir)
+        if not os.path.exists(self.certs_dir):
+            os.makedirs(self.certs_dir)
 
     def _load_state(self, local: bool) -> None:
         """
