@@ -47,6 +47,7 @@ DEFAULT_TO_SUPPLY = 0
 DEFAULT_VALUE = 0
 DEFAULT_LOCATION = {"longitude": 0.1270, "latitude": 51.5194}
 DEFAULT_SERVICE_DATA = {"key": "seller_service", "value": "erc1155_contract"}
+DEFAULT_GAS = 5000000
 
 
 class Strategy(Model):
@@ -97,6 +98,7 @@ class Strategy(Model):
         self._simple_service_data = {
             self._set_service_data["key"]: self._set_service_data["value"]
         }
+        self._gas = kwargs.pop("gas", DEFAULT_GAS)
 
         super().__init__(**kwargs)
         self._ledger_id = (
@@ -189,6 +191,11 @@ class Strategy(Model):
         )
         self._is_tokens_minted = is_tokens_minted
 
+    @property
+    def gas(self) -> int:
+        """Get gas."""
+        return self._gas
+
     def get_location_description(self) -> Description:
         """
         Get the location description.
