@@ -25,13 +25,18 @@ from aea.mail.base import EnvelopeContext
 from aea.skills.behaviours import TickerBehaviour
 
 from packages.fetchai.connections.ledger.base import CONNECTION_ID as LEDGER_API_ADDRESS
+from packages.fetchai.connections.prometheus.connection import (
+    PUBLIC_ID as PROM_CONNECTION_ID,
+)
 from packages.fetchai.contracts.oracle.contract import PUBLIC_ID as CONTRACT_PUBLIC_ID
 from packages.fetchai.protocols.contract_api.message import ContractApiMessage
 from packages.fetchai.protocols.ledger_api.message import LedgerApiMessage
+from packages.fetchai.protocols.prometheus.message import PrometheusMessage
 from packages.fetchai.skills.simple_oracle.dialogues import (
     ContractApiDialogue,
     ContractApiDialogues,
     LedgerApiDialogues,
+    PrometheusDialogues,
 )
 from packages.fetchai.skills.simple_oracle.strategy import Strategy
 
@@ -40,7 +45,7 @@ DEFAULT_UPDATE_INTERVAL = 5
 EXPIRATION_BLOCK = 1000000000000000
 
 
-class FetchOracleDeployer(TickerBehaviour):
+class SimpleOracleBehaviour(TickerBehaviour):
     """This class implements a behaviour that deploys a Fetch oracle contract."""
 
     def __init__(self, **kwargs):
@@ -68,6 +73,18 @@ class FetchOracleDeployer(TickerBehaviour):
         if strategy.is_oracle_role_granted:
             self.context.logger.info("Oracle role already granted")
 
+        prom_dialogues = cast(PrometheusDialogues, self.context.prometheus_dialogues)
+
+        if prom_dialogues.enabled:
+            for metric in prom_dialogues.metrics:
+                self.context.logger.info("Adding Prometheus metric: " + metric["name"])
+                self.add_prometheus_metric(
+                    metric["name"],
+                    metric["type"],
+                    metric["description"],
+                    dict(metric["labels"]),
+                )
+
     def act(self) -> None:
         """
         Implement the act.
@@ -77,6 +94,9 @@ class FetchOracleDeployer(TickerBehaviour):
 
         strategy = cast(Strategy, self.context.strategy)
 
+        # Request account balance
+        self._get_balance()
+
         if not strategy.is_contract_deployed:
             self.context.logger.info("Oracle contract not yet deployed")
             return
@@ -207,7 +227,11 @@ class FetchOracleDeployer(TickerBehaviour):
         self.context.logger.info("requesting update transaction...")
 
     def _get_balance(self):
+        """
+        Request balance of agent account by sending a message to the ledger API
 
+        :return: None
+        """
         strategy = cast(Strategy, self.context.strategy)
         ledger_api_dialogues = cast(
             LedgerApiDialogues, self.context.ledger_api_dialogues
@@ -225,6 +249,74 @@ class FetchOracleDeployer(TickerBehaviour):
             message=ledger_api_msg, context=envelope_context
         )
 
+    def add_prometheus_metric(
+        self,
+        metric_name: str,
+        metric_type: str,
+        description: str,
+        labels: Dict[str, str],
+    ) -> None:
+        """
+        Add a prometheus metric.
+
+        :param metric_name: the name of the metric to add.
+        :param type: the type of the metric.
+        :param description: a description of the metric.
+        :param labels: the metric labels.
+        :return: None
+        """
+
+        # context
+        prom_dialogues = cast(PrometheusDialogues, self.context.prometheus_dialogues)
+
+        # prometheus update message
+        message, _ = prom_dialogues.create(
+            counterparty=str(PROM_CONNECTION_ID),
+            performative=PrometheusMessage.Performative.ADD_METRIC,
+            type=metric_type,
+            title=metric_name,
+            description=description,
+            labels=labels,
+        )
+
+        # send message
+        envelope_context = EnvelopeContext(
+            skill_id=self.context.skill_id, connection_id=PROM_CONNECTION_ID
+        )
+        self.context.outbox.put_message(message=message, context=envelope_context)
+
+    def update_prometheus_metric(
+        self, metric_name: str, update_func: str, value: float, labels: Dict[str, str],
+    ) -> None:
+        """
+        Update a prometheus metric.
+
+        :param metric_name: the name of the metric.
+        :param update_func: the name of the update function (e.g. inc, dec, set, ...).
+        :param value: the value to provide to the update function.
+        :param labels: the metric labels.
+        :return: None
+        """
+
+        # context
+        prom_dialogues = cast(PrometheusDialogues, self.context.prometheus_dialogues)
+
+        # prometheus update message
+        message, _ = prom_dialogues.create(
+            counterparty=str(PROM_CONNECTION_ID),
+            performative=PrometheusMessage.Performative.UPDATE_METRIC,
+            title=metric_name,
+            callable=update_func,
+            value=value,
+            labels=labels,
+        )
+
+        # send message
+        envelope_context = EnvelopeContext(
+            skill_id=self.context.skill_id, connection_id=PROM_CONNECTION_ID
+        )
+        self.context.outbox.put_message(message=message, context=envelope_context)
+
     def teardown(self) -> None:
         """
         Implement the task teardown.
