@@ -236,3 +236,14 @@ _.unsupported_protocol_count
 _.unsupported_skill_count
 _.decoding_error_count
 _.ErrorHandler  # unused class (aea/error_handler/scaffold.py:27)
+ensure_dir  # unused function (aea/helpers/base.py:561)
+_.get_agent_overridables  # unused method (aea/manager/manager.py:419)
+_.set_agent_overrides  # unused method (aea/manager/manager.py:432)
+by_path  # unused function (aea/cli/fingerprint.py:94)
+AgentRecord  # unused class (aea/helpers/acn/agent_record.py:49)
+check_validity  # unused method (aea/helpers/acn/agent_record.py:96)
+signature_from_cert_request  # unused function (aea/helpers/acn/agent_record.py:51)
+Uri  # unused class (aea/helpers/acn/uri.py:26)
+not_before_string  # unused property (aea/helpers/base.py:724)
+not_after_string  # unused property (aea/helpers/base.py:729)
+from_cert_request  # unused method (aea/helpers/acn/agent_record.py:136)
