@@ -16,11 +16,10 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """Test module for Registry push methods."""
-
 import os
 from unittest import TestCase, mock
+from unittest.mock import mock_open
 
 import pytest
 from click import ClickException
@@ -36,7 +35,7 @@ from aea.configurations.base import PublicId
 from tests.test_cli.tools_for_testing import ContextMock, PublicIdMock
 
 
-@mock.patch("builtins.open", return_value="opened_file")
+@mock.patch("builtins.open", mock_open(read_data="opened_file"))
 @mock.patch("aea.cli.registry.push.check_is_author_logged_in")
 @mock.patch("aea.cli.registry.utils._rm_tarfiles")
 @mock.patch("aea.cli.registry.push.os.getcwd", return_value="cwd")
@@ -69,7 +68,6 @@ class PushItemTestCase(TestCase):
         getcwd_mock,
         rm_tarfiles_mock,
         check_is_author_logged_in_mock,
-        open_mock,
     ):
         """Test for push_item positive result."""
         public_id = PublicIdMock(
@@ -88,7 +86,7 @@ class PushItemTestCase(TestCase):
                 "protocols": ["protocol_id"],
             },
             is_auth=True,
-            files={"file": "opened_file", "readme": "opened_file"},
+            files={"file": open("file.1"), "readme": open("file.2")},
         )
 
     @mock.patch("aea.cli.registry.push.os.path.exists", return_value=True)
@@ -113,7 +111,7 @@ class PushItemTestCase(TestCase):
                 "protocols": ["protocol_id"],
             },
             is_auth=True,
-            files={"file": "opened_file"},
+            files={"file": open("opened_file", "r")},
         )
 
     @mock.patch("aea.cli.registry.push.os.path.exists", return_value=False)
@@ -126,7 +124,6 @@ class PushItemTestCase(TestCase):
         getcwd_mock,
         rm_tarfiles_mock,
         check_is_author_logged_in_mock,
-        open_mock,
     ):
         """Test for push_item - item not found."""
         with self.assertRaises(ClickException):
