@@ -17,6 +17,7 @@
 #
 # ------------------------------------------------------------------------------
 
+
 """This module contains the tests for the aea.configurations.loader module."""
 import os
 from pathlib import Path
@@ -28,7 +29,8 @@ import yaml
 
 import aea
 from aea.configurations.base import PackageType, ProtocolSpecification
-from aea.configurations.loader import ConfigLoader, make_jsonschema_base_uri
+from aea.configurations.loader import ConfigLoader
+from aea.configurations.validation import OwnDraft4Validator, make_jsonschema_base_uri
 from aea.protocols.generator.common import load_protocol_specification
 
 from tests.conftest import protocol_specification_files
@@ -55,8 +57,8 @@ def test_config_loader_dump_component():
     """Test ConfigLoader.dump"""
     config_loader = ConfigLoader.from_configuration_type(PackageType.PROTOCOL)
     configuration = MagicMock()
-    with mock.patch.object(aea.configurations.loader, "yaml_dump"), mock.patch(
-        "jsonschema.Draft4Validator.validate"
+    with mock.patch.object(aea.configurations.loader, "yaml_dump"), mock.patch.object(
+        OwnDraft4Validator, "validate"
     ), mock.patch("builtins.open"):
         config_loader.dump(configuration, open("foo"))
 
@@ -65,9 +67,9 @@ def test_config_loader_dump_agent_config():
     """Test ConfigLoader.dump"""
     config_loader = ConfigLoader.from_configuration_type(PackageType.AGENT)
     configuration = MagicMock(ordered_json={"component_configurations": []})
-    with mock.patch.object(aea.configurations.loader, "yaml_dump_all"), mock.patch(
-        "jsonschema.Draft4Validator.validate"
-    ), mock.patch("builtins.open"):
+    with mock.patch.object(
+        aea.configurations.loader, "yaml_dump_all"
+    ), mock.patch.object(OwnDraft4Validator, "validate"), mock.patch("builtins.open"):
         config_loader.dump(configuration, open("foo"))
 
 
@@ -90,7 +92,7 @@ def test_load_protocol_specification_only_first_part():
     )
     with mock.patch.object(
         yaml, "safe_load_all", return_value=[valid_protocol_specification]
-    ), mock.patch("builtins.open"), mock.patch("jsonschema.Draft4Validator.validate"):
+    ), mock.patch("builtins.open"), mock.patch.object(OwnDraft4Validator, "validate"):
         load_protocol_specification("foo")
 
 
@@ -108,7 +110,7 @@ def test_load_protocol_specification_two_parts():
         yaml,
         "safe_load_all",
         return_value=[valid_protocol_specification, valid_protocol_specification],
-    ), mock.patch("builtins.open"), mock.patch("jsonschema.Draft4Validator.validate"):
+    ), mock.patch("builtins.open"), mock.patch.object(OwnDraft4Validator, "validate"):
         load_protocol_specification("foo")
 
 
