@@ -202,6 +202,21 @@ def test_get_balance():
     assert balance > 0, "Existing account has no balance."
 
 
+# @pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)
+@pytest.mark.integration
+@pytest.mark.ledger
+def test_get_state():
+    """Test that get_state() with 'blocks' function returns something containing the block height."""
+    fetchai_api = FetchAIApi(**FETCHAI_TESTNET_CONFIG)
+    callable_name = "blocks"
+    args = ("latest",)
+    block = fetchai_api.get_state(callable_name, *args)
+    assert block is not None, "No response to 'blocks/latest' query."
+    assert (
+        block["block"]["header"]["height"] is not None
+    ), "Block height not found in response."
+
+
 def get_wealth(address: str):
     """Get wealth for test."""
     fetchai_api = FetchAIApi(**FETCHAI_TESTNET_CONFIG)
