@@ -199,7 +199,7 @@ def test_get_state_serialization():
 
 def test_state_serialization():
     """Test the serialization for 'state' speech-act works."""
-    state_arg = ContractApiMessage.State("some_ledger_id", b"some_body")
+    state_arg = ContractApiMessage.State("some_ledger_id", {"key": "some_body"})
     msg = ContractApiMessage(
         message_id=1,
         dialogue_reference=(str(0), ""),
@@ -233,7 +233,7 @@ def test_state_serialization():
 def test_raw_transaction_serialization():
     """Test the serialization for 'raw_transaction' speech-act works."""
     raw_transaction_arg = ContractApiMessage.RawTransaction(
-        "some_ledger_id", b"some_body"
+        "some_ledger_id", {"body": "some_body"}
     )
     msg = ContractApiMessage(
         message_id=2,
@@ -415,9 +415,6 @@ def test_kwargs():
     kwargs = ContractApiMessage.Kwargs(body)
     assert str(kwargs) == "Kwargs: body={}".format(body)
 
-    with pytest.raises(ValueError, match="body must not be None"):
-        ContractApiMessage.Kwargs(None)
-
 
 class TestDialogues:
     """Tests contract_api dialogues."""
