@@ -53,14 +53,18 @@ class TestCoinPriceSkill(AEATestCaseEmpty):
 
     def test_coin_price(self):
         """Run the coin price skill sequence."""
+
+        coin_price_feed_aea_name = self.agent_name
+
         self.add_item("connection", "fetchai/http_client:0.16.0")
         self.add_item("connection", "fetchai/http_server:0.15.0")
         self.add_item("connection", "fetchai/prometheus:0.2.0")
+        self.remove_item("connection", "fetchai/stub:0.15.0")
         self.add_item("skill", "fetchai/coin_price:0.3.0")
         self.set_config("agent.default_connection", "fetchai/http_server:0.15.0")
 
         default_routing = {
-            "fetchai/http:0.13.0": "fetchai/http_client:0.16.0",
+            "fetchai/http:0.11.0": "fetchai/http_client:0.16.0",
             "fetchai/prometheus:0.2.0": "fetchai/prometheus:0.2.0",
         }
         setting_path = "agent.default_routing"
@@ -75,6 +79,13 @@ class TestCoinPriceSkill(AEATestCaseEmpty):
             type_="bool",
         )
 
+        diff = self.difference_to_fetched_agent(
+            "fetchai/coin_price_feed:0.4.0", coin_price_feed_aea_name
+        )
+        assert (
+            diff == []
+        ), "Difference between created and fetched project for files={}".format(diff)
+
         self.run_install()
 
         process = self.run_agent()
